import { ComponentOptionsMixin } from 'vue';
import { DataObject } from './typings';
import { DefineComponent } from 'vue';
import { Direction } from './typings';
import { Dot } from './typings';
import { DotOption } from './typings';
import { DotOption as DotOption_2 } from '../typings';
import { ExtractPropTypes } from 'vue';
import { Mark } from '../typings';
import { Mark as Mark_2 } from './typings';
import { MarksProp } from './typings';
import { MarksProp as MarksProp_2 } from '../typings';
import { Position } from './typings';
import { Process } from './typings';
import { ProcessOption } from '../typings';
import { ProcessProp } from './typings';
import { ProcessProp as ProcessProp_2 } from '../typings';
import { PropType } from 'vue';
import { PublicProps } from 'vue';
import { Styles } from './typings';
import { TooltipFormatter } from './typings';
import { TooltipProp } from './typings';
import { Value } from './typings';
import { Value as Value_2 } from '../typings';

/**
 * Slider logic control center
 *
 * @export
 * @class Control
 */
declare class Control {
    dotsPos: number[];
    dotsValue: Value_2[];
    data?: Value_2[];
    enableCross: boolean;
    fixed: boolean;
    max: number;
    min: number;
    interval: number;
    minRange: number;
    maxRange: number;
    order: boolean;
    marks?: MarksProp_2;
    included?: boolean;
    process?: ProcessProp_2;
    adsorb?: boolean;
    dotOptions?: DotOption_2 | DotOption_2[];
    onError?: (type: ERROR_TYPE, message: string) => void;
    constructor(options: {
        value: Value_2 | Value_2[];
        data?: Value_2[];
        enableCross: boolean;
        fixed: boolean;
        max: number;
        min: number;
        interval: number;
        order: boolean;
        minRange?: number;
        maxRange?: number;
        marks?: MarksProp_2;
        included?: boolean;
        process?: ProcessProp_2;
        adsorb?: boolean;
        dotOptions?: DotOption_2 | DotOption_2[];
        onError?: (type: ERROR_TYPE, message: string) => void;
    });
    setValue(value: Value_2 | Value_2[]): void;
    setDotsValue(value: Value_2[], syncPos?: boolean): void;
    setDotsPos(dotsPos: number[]): void;
    getValueByPos(pos: number): Value_2;
    syncDotsPos(): void;
    /**
     * Get all the marks
     *
     * @readonly
     * @type {Mark[]}
     * @memberof Control
     */
    get markList(): Mark[];
    /**
     * Get the most recent slider index by position
     *
     * @param {number} pos
     * @returns {number}
     * @memberof Control
     */
    getRecentDot(pos: number): number;
    /**
     * Get index by value
     *
     * @param {Value} value
     * @returns {number}
     * @memberof Control
     */
    getIndexByValue(value: Value_2): number;
    /**
     * Get value by index
     *
     * @param {index} number
     * @returns {Value}
     * @memberof Control
     */
    getValueByIndex(index: number): Value_2;
    /**
     * Set the position of a single slider
     *
     * @param {number} pos
     * @param {number} index
     */
    setDotPos(pos: number, index: number): void;
    /**
     * In fixed mode, get the position of all slider changes
     *
     * @param {number} changePos Change distance of a single slider
     * @param {number} index slider index
     * @returns {DotsPosChangeArray}
     * @memberof Control
     */
    private getFixedChangePosArr;
    /**
     * In minRange/maxRange mode, get the position of all slider changes
     *
     * @param {number} pos position of a single slider
     * @param {number} changePos Change distance of a single slider
     * @param {number} index slider index
     * @returns {DotsPosChangeArray}
     * @memberof Control
     */
    private getLimitRangeChangePosArr;
    private isPos;
    /**
     * Get a valid position by pos
     *
     * @param {number} pos
     * @param {number} index
     * @returns {{ pos: number, inRange: boolean }}
     */
    getValidPos(pos: number, index: number): {
        pos: number;
        inRange: boolean;
    };
    /**
     * Calculate the position of the slider by value
     *
     * @param {Value} val
     * @returns {number}
     */
    parseValue(val: Value_2): number;
    /**
     * Calculate the value by position
     *
     * @param {number} pos
     * @returns {Value}
     * @memberof Control
     */
    parsePos(pos: number): Value_2;
    /**
     * Determine if the location is active
     *
     * @param {number} pos
     * @returns {boolean}
     * @memberof Control
     */
    isActiveByPos(pos: number): boolean;
    /**
     * Get each value
     *
     * @returns {Value[]}
     * @memberof Control
     */
    getValues(): Value_2[];
    /**
     * Calculate the distance of the range
     * @param range number
     */
    getRangeDir(range: number): number;
    private emitError;
    get processArray(): ProcessOption;
    /**
     * The total number of values
     *
     * @type {number}
     * @memberof Control
     */
    get total(): number;
    get gap(): number;
    private cacheRangeDir;
    get minRangeDir(): number;
    get maxRangeDir(): number;
    private getDotRange;
    /**
     * Sliding range of each slider
     *
     * @type {Array<[number, number]>}
     * @memberof Control
     */
    get valuePosRange(): Array<[number, number]>;
    get dotsIndex(): number[];
}

declare const _default: DefineComponent<{
    modelValue: {
        type: PropType<Value | Value[]>;
        default: Value;
    };
    silent: {
        type: BooleanConstructor;
        default: boolean;
    };
    direction: {
        type: PropType<Direction>;
        default: string;
        validator: (dir: Direction) => boolean;
    };
    width: {
        type: (StringConstructor | NumberConstructor)[];
    };
    height: {
        type: (StringConstructor | NumberConstructor)[];
    };
    dotSize: {
        type: PropType<number | [number, number]>;
        default: number;
    };
    contained: {
        type: BooleanConstructor;
        default: boolean;
    };
    min: {
        type: NumberConstructor;
        default: number;
    };
    max: {
        type: NumberConstructor;
        default: number;
    };
    interval: {
        type: NumberConstructor;
        default: number;
    };
    disabled: {
        type: BooleanConstructor;
        default: boolean;
    };
    clickable: {
        type: BooleanConstructor;
        default: boolean;
    };
    dragOnClick: {
        type: BooleanConstructor;
        default: boolean;
    };
    duration: {
        type: NumberConstructor;
        default: number;
    };
    data: {
        type: PropType<Value[] | object[] | DataObject>;
    };
    dataValue: {
        type: StringConstructor;
        default: string;
    };
    dataLabel: {
        type: StringConstructor;
        default: string;
    };
    lazy: {
        type: BooleanConstructor;
        default: boolean;
    };
    tooltip: {
        type: PropType<TooltipProp>;
        default: TooltipProp;
        validator: (val: string) => boolean;
    };
    tooltipPlacement: {
        type: PropType<Position | Position[]>;
        validator: (val: string | string[]) => boolean;
    };
    tooltipFormatter: {
        type: PropType<TooltipFormatter | TooltipFormatter[]>;
    };
    useKeyboard: {
        type: BooleanConstructor;
        default: boolean;
    };
    keydownHook: {
        type: PropType<(e: KeyboardEvent) => HandleFunction | boolean>;
    };
    enableCross: {
        type: BooleanConstructor;
        default: boolean;
    };
    fixed: {
        type: BooleanConstructor;
        default: boolean;
    };
    order: {
        type: BooleanConstructor;
        default: boolean;
    };
    minRange: {
        type: NumberConstructor;
    };
    maxRange: {
        type: NumberConstructor;
    };
    marks: {
        type: PropType<MarksProp>;
        default: MarksProp;
    };
    process: {
        type: PropType<ProcessProp>;
        default: ProcessProp;
    };
    zoom: {
        type: NumberConstructor;
    };
    included: {
        type: BooleanConstructor;
    };
    adsorb: {
        type: BooleanConstructor;
    };
    hideLabel: {
        type: BooleanConstructor;
    };
    dotOptions: {
        type: PropType<DotOption | DotOption[]>;
    };
    dotAttrs: {
        type: ObjectConstructor;
    };
    railStyle: {
        type: PropType<Styles>;
    };
    processStyle: {
        type: PropType<Styles>;
    };
    dotStyle: {
        type: PropType<Styles>;
    };
    tooltipStyle: {
        type: PropType<Styles>;
    };
    stepStyle: {
        type: PropType<Styles>;
    };
    stepActiveStyle: {
        type: PropType<Styles>;
    };
    labelStyle: {
        type: PropType<Styles>;
    };
    labelActiveStyle: {
        type: PropType<Styles>;
    };
}, unknown, {
    control: Control | null;
    states: State;
    scale: number;
    focusDotIndex: number;
}, {
    isHorizontal(): boolean;
    isReverse(): boolean;
    tailSize(): string;
    containerClasses(): (string | string[] | {
        'vue-slider-disabled': boolean;
    })[];
    containerStyles(): {
        padding: string;
        width: string;
        height: string;
    };
    processArray(): Process[];
    dotBaseStyle(): {
        width: string;
        height: string;
    };
    mainDirection(): string;
    tooltipDirections(): Position[];
    dots(): Dot[];
    animateTime(): number;
    canSort(): boolean;
    sliderData(): undefined | Value[];
    sliderMarks(): MarksProp | undefined;
    sliderTooltipFormatter(): TooltipFormatter | TooltipFormatter[] | undefined;
    isNotSync(): boolean;
    /**
     * Get the drag range of the slider
     *
     * @private
     * @param {number} index slider index
     * @returns {[number, number]} range [start, end]
     * @memberof VueSlider
     */
    dragRange(): [number, number];
}, {
    isObjectData(data?: Value[] | object[] | DataObject): data is DataObject;
    isObjectArrayData(data?: Value[] | object[] | DataObject): data is object[];
    bindEvent(): void;
    unbindEvent(): void;
    setScale(): void;
    initControl(): void;
    syncValueByPos(): void;
    isDiff(value1: Value[], value2: Value[]): boolean;
    emitError(type: ERROR_TYPE, message: string): void;
    dragStartOnProcess(e: MouseEvent | TouchEvent): void;
    dragStart(index: number): void;
    dragMove(e: MouseEvent | TouchEvent): false | undefined;
    isCrossDot(pos: number): void;
    dragEnd(e: MouseEvent | TouchEvent): false | undefined;
    blurHandle(e: MouseEvent): false | undefined;
    clickHandle(e: MouseEvent | TouchEvent): false | undefined;
    focus(dot: Dot, index?: number): void;
    blur(): void;
    getValue(): Value | Value[];
    getIndex(): number | number[];
    setValue(value: Value | Value[]): void;
    setIndex(index: number | number[]): void;
    setValueByPos(pos: number): false | undefined;
    keydownHandle(e: KeyboardEvent): false | undefined;
    getPosByEvent(e: MouseEvent | TouchEvent): number;
    renderSlot<T>(name: string, data: T, defaultSlot: any): any;
}, ComponentOptionsMixin, ComponentOptionsMixin, ("drag-start" | "change" | "dragging" | "drag-end" | "error" | "update:modelValue")[], "drag-start" | "change" | "dragging" | "drag-end" | "error" | "update:modelValue", PublicProps, Readonly<ExtractPropTypes<{
    modelValue: {
        type: PropType<Value | Value[]>;
        default: Value;
    };
    silent: {
        type: BooleanConstructor;
        default: boolean;
    };
    direction: {
        type: PropType<Direction>;
        default: string;
        validator: (dir: Direction) => boolean;
    };
    width: {
        type: (StringConstructor | NumberConstructor)[];
    };
    height: {
        type: (StringConstructor | NumberConstructor)[];
    };
    dotSize: {
        type: PropType<number | [number, number]>;
        default: number;
    };
    contained: {
        type: BooleanConstructor;
        default: boolean;
    };
    min: {
        type: NumberConstructor;
        default: number;
    };
    max: {
        type: NumberConstructor;
        default: number;
    };
    interval: {
        type: NumberConstructor;
        default: number;
    };
    disabled: {
        type: BooleanConstructor;
        default: boolean;
    };
    clickable: {
        type: BooleanConstructor;
        default: boolean;
    };
    dragOnClick: {
        type: BooleanConstructor;
        default: boolean;
    };
    duration: {
        type: NumberConstructor;
        default: number;
    };
    data: {
        type: PropType<Value[] | object[] | DataObject>;
    };
    dataValue: {
        type: StringConstructor;
        default: string;
    };
    dataLabel: {
        type: StringConstructor;
        default: string;
    };
    lazy: {
        type: BooleanConstructor;
        default: boolean;
    };
    tooltip: {
        type: PropType<TooltipProp>;
        default: TooltipProp;
        validator: (val: string) => boolean;
    };
    tooltipPlacement: {
        type: PropType<Position | Position[]>;
        validator: (val: string | string[]) => boolean;
    };
    tooltipFormatter: {
        type: PropType<TooltipFormatter | TooltipFormatter[]>;
    };
    useKeyboard: {
        type: BooleanConstructor;
        default: boolean;
    };
    keydownHook: {
        type: PropType<(e: KeyboardEvent) => HandleFunction | boolean>;
    };
    enableCross: {
        type: BooleanConstructor;
        default: boolean;
    };
    fixed: {
        type: BooleanConstructor;
        default: boolean;
    };
    order: {
        type: BooleanConstructor;
        default: boolean;
    };
    minRange: {
        type: NumberConstructor;
    };
    maxRange: {
        type: NumberConstructor;
    };
    marks: {
        type: PropType<MarksProp>;
        default: MarksProp;
    };
    process: {
        type: PropType<ProcessProp>;
        default: ProcessProp;
    };
    zoom: {
        type: NumberConstructor;
    };
    included: {
        type: BooleanConstructor;
    };
    adsorb: {
        type: BooleanConstructor;
    };
    hideLabel: {
        type: BooleanConstructor;
    };
    dotOptions: {
        type: PropType<DotOption | DotOption[]>;
    };
    dotAttrs: {
        type: ObjectConstructor;
    };
    railStyle: {
        type: PropType<Styles>;
    };
    processStyle: {
        type: PropType<Styles>;
    };
    dotStyle: {
        type: PropType<Styles>;
    };
    tooltipStyle: {
        type: PropType<Styles>;
    };
    stepStyle: {
        type: PropType<Styles>;
    };
    stepActiveStyle: {
        type: PropType<Styles>;
    };
    labelStyle: {
        type: PropType<Styles>;
    };
    labelActiveStyle: {
        type: PropType<Styles>;
    };
}>> & {
    onChange?: ((...args: any[]) => any) | undefined;
    onError?: ((...args: any[]) => any) | undefined;
    "onDrag-start"?: ((...args: any[]) => any) | undefined;
    onDragging?: ((...args: any[]) => any) | undefined;
    "onDrag-end"?: ((...args: any[]) => any) | undefined;
    "onUpdate:modelValue"?: ((...args: any[]) => any) | undefined;
}, {
    hideLabel: boolean;
    min: number;
    max: number;
    tooltip: TooltipProp;
    disabled: boolean;
    modelValue: Value | Value[];
    silent: boolean;
    direction: Direction;
    dotSize: number | [number, number];
    contained: boolean;
    interval: number;
    clickable: boolean;
    dragOnClick: boolean;
    duration: number;
    dataValue: string;
    dataLabel: string;
    lazy: boolean;
    useKeyboard: boolean;
    enableCross: boolean;
    fixed: boolean;
    order: boolean;
    marks: MarksProp;
    process: ProcessProp;
    included: boolean;
    adsorb: boolean;
}, {}>;
export default _default;

export declare const enum ERROR_TYPE {
    VALUE = 1,
    INTERVAL = 2,
    MIN = 3,
    MAX = 4,
    ORDER = 5
}

declare type HandleFunction = (index: number) => number;

declare class State {
    map: StateMap;
    states: number;
    constructor(map: StateMap);
    add(state: number): void;
    delete(state: number): void;
    toggle(state: number): void;
    has(state: number): boolean;
}

declare interface StateMap {
    [key: string]: number;
}

export declare const VueSliderDot: DefineComponent<{
    value: {
        type: PropType<Value>;
        default: number;
    };
    tooltip: {
        type: PropType<TooltipProp>;
        required: true;
    };
    tooltipPlacement: {
        type: PropType<Position>;
        validator: (val: string) => boolean;
        required: true;
    };
    tooltipFormatter: {
        type: PropType<TooltipFormatter>;
    };
    focus: {
        type: BooleanConstructor;
        default: boolean;
    };
    disabled: {
        type: BooleanConstructor;
        default: boolean;
    };
    dotStyle: {
        type: PropType<Styles>;
    };
    tooltipStyle: {
        type: PropType<Styles>;
    };
}, unknown, unknown, {
    dotClasses(): (string | {
        'vue-slider-dot-hover': boolean;
        'vue-slider-dot-disabled': boolean;
        'vue-slider-dot-focus': boolean;
    })[];
    handleClasses(): (string | {
        'vue-slider-dot-handle-disabled': boolean;
        'vue-slider-dot-handle-focus': boolean;
    })[];
    tooltipClasses(): (string | string[] | {
        'vue-slider-dot-tooltip-show': boolean;
    })[];
    tooltipInnerClasses(): (string | string[] | {
        'vue-slider-dot-tooltip-inner-disabled': boolean;
        'vue-slider-dot-tooltip-inner-focus': boolean;
    })[];
    showTooltip(): boolean;
    tooltipValue(): Value;
}, {
    dragStart(): false | undefined;
}, ComponentOptionsMixin, ComponentOptionsMixin, "drag-start"[], "drag-start", PublicProps, Readonly<ExtractPropTypes<{
    value: {
        type: PropType<Value>;
        default: number;
    };
    tooltip: {
        type: PropType<TooltipProp>;
        required: true;
    };
    tooltipPlacement: {
        type: PropType<Position>;
        validator: (val: string) => boolean;
        required: true;
    };
    tooltipFormatter: {
        type: PropType<TooltipFormatter>;
    };
    focus: {
        type: BooleanConstructor;
        default: boolean;
    };
    disabled: {
        type: BooleanConstructor;
        default: boolean;
    };
    dotStyle: {
        type: PropType<Styles>;
    };
    tooltipStyle: {
        type: PropType<Styles>;
    };
}>> & {
    "onDrag-start"?: ((...args: any[]) => any) | undefined;
}, {
    value: Value;
    focus: boolean;
    disabled: boolean;
}, {}>;

export declare const VueSliderMark: DefineComponent<{
    mark: {
        type: PropType<Mark_2>;
        required: true;
    };
    hideLabel: {
        type: BooleanConstructor;
    };
    stepStyle: {
        type: PropType<Styles>;
        default: () => {};
    };
    stepActiveStyle: {
        type: PropType<Styles>;
        default: () => {};
    };
    labelStyle: {
        type: PropType<Styles>;
        default: () => {};
    };
    labelActiveStyle: {
        type: PropType<Styles>;
        default: () => {};
    };
}, unknown, unknown, {
    marksClasses(): (string | {
        'vue-slider-mark-active': boolean | undefined;
    })[];
    stepClasses(): (string | {
        'vue-slider-mark-step-active': boolean | undefined;
    })[];
    labelClasses(): (string | {
        'vue-slider-mark-label-active': boolean | undefined;
    })[];
}, {
    labelClickHandle(e: MouseEvent | TouchEvent): void;
}, ComponentOptionsMixin, ComponentOptionsMixin, "press-label"[], "press-label", PublicProps, Readonly<ExtractPropTypes<{
    mark: {
        type: PropType<Mark_2>;
        required: true;
    };
    hideLabel: {
        type: BooleanConstructor;
    };
    stepStyle: {
        type: PropType<Styles>;
        default: () => {};
    };
    stepActiveStyle: {
        type: PropType<Styles>;
        default: () => {};
    };
    labelStyle: {
        type: PropType<Styles>;
        default: () => {};
    };
    labelActiveStyle: {
        type: PropType<Styles>;
        default: () => {};
    };
}>> & {
    "onPress-label"?: ((...args: any[]) => any) | undefined;
}, {
    hideLabel: boolean;
    stepStyle: Styles;
    stepActiveStyle: Styles;
    labelStyle: Styles;
    labelActiveStyle: Styles;
}, {}>;

export { }
